@@ -6,6 +6,7 @@ QUERY__fetch_email_template_by_name = "SELECT * FROM jaaql__email_template WHERE
 QUERY__make_user_public = "UPDATE jaaql__user SET public_credentials = concat(:username, ':', :new_password), application = :application, is_public = TRUE WHERE deleted is null AND id = :user_id"
 QUERY__fetch_url_from_application_name = "SELECT url FROM jaaql__application WHERE name = :application"
 QUERY__fetch_application_public_user_credentials = "SELECT split_part(public_credentials, ':', 1) as username, split_part(public_credentials, ':', 2) as password FROM jaaql__user WHERE application = :application"
+QUERY__fetch_application_default_templates = "SELECT jet.name as template, jet2.name as existing_user_template FROM jaaql__application ja LEFT JOIN jaaql__email_template jet ON jet.id = ja.default_email_signup_template LEFT JOIN jaaql__email_template jet2 ON jet.id = ja.default_email_already_signed_up_template WHERE ja.application = :application AND ja.deleted is NULL"
 QUERY__my_roles = "SELECT rolname FROM pg_roles WHERE pg_has_role(oid, 'member');"
 QUERY__grant_role = "GRANT %s TO %s"
 QUERY__default_roles_sel = "SELECT * FROM jaaql__default_role"
@@ -16,7 +17,7 @@ QUERY__application_set_url = "UPDATE jaaql__application SET url = :url WHERE nam
 QUERY__application_ins = "INSERT INTO jaaql__application (name, description, url) VALUES (:name, :description, :url)"
 QUERY__application_setup_host = "INSERT INTO jaaql__assigned_database (application, configuration, database, node, dataset) VALUES (:application, 'host', '%s', '%s', 'node')" % (DB__jaaql, NODE__host_node)
 QUERY__application_del = "DELETE FROM jaaql__application WHERE name = :name"
-QUERY__application_sel = "SELECT * FROM jaaql__application"
+QUERY__application_sel = "SELECT ja.name, ja.description, ja.url, ja.created, jet.name as default_email_signup_template, jet2.name as default_email_already_signed_up_template FROM jaaql__application ja LEFT JOIN jaaql__email_template jet ON jet.id = ja.default_email_signup_template LEFT JOIN jaaql__email_template jet2 ON jet2.id = ja.default_email_already_signed_up_template"
 QUERY__application_count = "SELECT COUNT(*) FROM jaaql__application"
 QUERY__application_upd = "UPDATE jaaql__application SET name = coalesce(:new_name, name), description = coalesce(:new_description, description), url = coalesce(:new_url, url) WHERE name = :name"
 QUERY__database_ins = "INSERT INTO jaaql__database (node, name) VALUES (:node, :name)"
